@@ -1,8 +1,19 @@
 from typing import List
 
+from databases import Database
 from ormar import Boolean, Integer, Model, String
+from sqlalchemy import MetaData, create_engine  # type: ignore[import]
 
-from kolombo.resources import database, metadata
+from kolombo import conf
+
+database = Database(conf.DATABASE_URL)
+metadata = MetaData()
+
+
+async def init_database() -> None:
+    await database.connect()
+    engine = create_engine(conf.DATABASE_URL)
+    metadata.create_all(engine)
 
 
 class Domain(Model):
@@ -21,7 +32,7 @@ class Domain(Model):
 
     @classmethod
     async def all_active(cls) -> List["Domain"]:
-        return await cls.objects.filter(active=True).all()  # type: ignore[return-value]
+        return await cls.objects.filter(active=True).all()
 
 
 class User(Model):
@@ -42,4 +53,4 @@ class User(Model):
 
     @classmethod
     async def all_active(cls) -> List["User"]:
-        return await cls.objects.filter(active=True).all()  # type: ignore[return-value]
+        return await cls.objects.filter(active=True).all()
